@@ -1,6 +1,8 @@
 #include "muscle.h"
 #include "myutils.h"
 
+string g_Arg1;
+
 int main(int argc, char **argv)
 	{
 	for (int i = 1; i < argc; ++i)
@@ -15,8 +17,8 @@ int main(int argc, char **argv)
 
 		if (s == "-help" || s == "--help")
 			{
-			void Help();
-			Help();
+			void Usage(FILE *f);
+			Usage(stdout);
 			return 0;
 			}
 		}
@@ -32,6 +34,24 @@ int main(int argc, char **argv)
 	SetLogFileName(opt(log));
 	LogProgramInfoAndCmdLine();
 
+	extern vector<string> g_Argv;
+	uint n = SIZE(g_Argv);
+	asserta(n > 0);
+	string ShortCmdLine;
+	if (n > 1)
+		ShortCmdLine = g_Argv[1];
+	if (n > 2)
+		{
+		g_Arg1 = g_Argv[2];
+		ShortCmdLine += " " + g_Argv[2];
+		}
+	if (n > 1)
+		{
+		ProgressPrefix(false);
+		Progress("[%s]\n", ShortCmdLine.c_str() + 1);
+		ProgressPrefix(true);
+		}
+
 	uint CmdCount = 0;
 #define C(x)	if (optset_##x) ++CmdCount;
 #include "cmds.h"
@@ -41,6 +61,8 @@ int main(int argc, char **argv)
 #define C(x)	\
 	if (optset_##x) \
 		{ \
+		g_Arg1 = opt_##x; \
+		optused_##x = true; \
 		void cmd_##x(); \
 		cmd_##x(); \
 		CheckUsedOpts(false); \
