@@ -330,7 +330,7 @@ void TransAln::Init(const MultiSequence &MSA,
 		m_MSAPaths.push_back(MSAPath);
 
 		const Sequence *Seq = MSA.GetSequence(MSAIndex);
-		Sequence *UngappedSeq = Seq->DeleteGaps();
+		Sequence *UngappedSeq = Seq->CopyDeleteGaps();
 		m_UngappedMSASeqs.push_back(UngappedSeq);
 		}
 
@@ -661,8 +661,6 @@ Sequence *TransAln::ExtendFreshSeq(uint FreshIndex) const
 	uint MSACol = 0;
 	Sequence *FX = Sequence::NewSequence();
 	FX->InitData();
-	uint GSI = F.GetGSI();
-	FX->SetGSI(GSI);
 	FX->m_Label = F.m_Label;
 	uint FPos = 0;
 	for (uint Col = 0; Col < ColCount; ++Col)
@@ -704,8 +702,6 @@ Sequence *TransAln::ExtendMSASeq(uint MSAIndex) const
 	uint MSACol = 0;
 	Sequence *MX = Sequence::NewSequence();
 	MX->InitData();
-	uint GSI = M.GetGSI();
-	MX->SetGSI(GSI);
 	MX->m_Label = M.m_Label;
 	for (uint Col = 0; Col < ColCount; ++Col)
 		{
@@ -771,7 +767,7 @@ void cmd_transaln()
 	for (uint i = 0; i < RefSeqCount; ++i)
 		{
 		const Sequence *AlignedRefSeq = RefMSA.GetSequence(i);
-		Sequence *UngappedRefSeq = AlignedRefSeq->DeleteGaps();
+		Sequence *UngappedRefSeq = AlignedRefSeq->CopyDeleteGaps();
 		UngappedRefSeqs.AddSequence(UngappedRefSeq, true);
 		}
 
@@ -784,9 +780,11 @@ void cmd_transaln()
 
 		const Sequence *InputSeq = InputSeqs.GetSequence(InputSeqIndex);
 		const Sequence *RefSeq = UngappedRefSeqs.GetSequence(RefSeqIndex);
+		const string &InputLabel = InputSeq->m_Label;
+		const string &RefLabel = RefSeq->m_Label;
 
 		string PWPath;
-		AlignPairFlat(InputSeq, RefSeq, PWPath);
+		AlignPairFlat(InputLabel, RefLabel, PWPath);
 
 		PWPaths.push_back(PWPath);
 		}
